Point2Soa

Struct Point2Soa 

pub struct Point2Soa<L: Copy + Debug + 'static, const N: usize> {
    pub len: usize,
    pub x: [L; N],
    pub y: [L; N],
}

Fields

len: usizex: [L; N]y: [L; N]

Implementations

Source

impl<L: Copy + Debug + 'static, const N: usize> Point2Soa<L, N>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

Source

impl<L, const N: usize> Point2Soa<L, N>
where L: Clone + Default + Copy + Debug + 'static,

pub fn new(default: Point2<L>) -> Self

pub fn push(&mut self, value: Point2<L>)

pub fn pop(&mut self) -> Option<Point2<L>>

pub fn set(&mut self, index: usize, value: Point2<L>)

pub fn get(&self, index: usize) -> Point2<L>

pub fn apply<F>(&mut self, f: F)
where F: FnMut(L, L) -> (L, L),

pub fn iter(&self) -> Point2Iterator<'_, L, N>

pub fn x(&self) -> &[L]

pub fn x_mut(&mut self) -> &mut [L]

pub fn x_range(&self, range: Range<usize>) -> &[L]

pub fn x_range_mut(&mut self, range: Range<usize>) -> &mut [L]

pub fn y(&self) -> &[L]

pub fn y_mut(&mut self) -> &mut [L]

pub fn y_range(&self, range: Range<usize>) -> &[L]

pub fn y_range_mut(&mut self, range: Range<usize>) -> &mut [L]

Source

impl<const N: usize> Point2Soa<Length, N>

pub fn distances_squared(&self, target: Point2<Length32>, out: &mut [Area32])

Squared distance from every point to target, written to out[..len]. Sqrt-free, so the loop vectorizes; enough for nearest-neighbor style comparisons. Accurate to 1 ulp.

Panics

If out is shorter than self.len().

pub fn distances(&self, target: Point2<Length32>, out: &mut [Length32])

Distance from every point to target, written to out[..len].

Panics

If out is shorter than self.len().

pub fn lerp_toward(&mut self, target: Point2<Length32>, ratio: f32)

Every point moved ratio of the way toward target, in place.

Source

impl<const N: usize> Point2Soa<Length, N>

pub fn distances_squared(&self, target: Point2<Length64>, out: &mut [Area64])

Squared distance from every point to target, written to out[..len]. Sqrt-free, so the loop vectorizes; enough for nearest-neighbor style comparisons. Accurate to 1 ulp.

Panics

If out is shorter than self.len().

pub fn distances(&self, target: Point2<Length64>, out: &mut [Length64])

Distance from every point to target, written to out[..len].

Panics

If out is shorter than self.len().

pub fn lerp_toward(&mut self, target: Point2<Length64>, ratio: f64)

Every point moved ratio of the way toward target, in place.